@@ -12,30 +12,30 @@
  * accessing Messreihen on the server.
  */
 qx.Class.define('callbackery.data.RemoteTableModel', {
-    extend : qx.ui.table.model.Remote,
+    extend: qx.ui.table.model.Remote,
 
     /**
      * Create an instance of Rpc.
      */
-    construct : function(cfg,getParentFormData) {
+    construct: function(cfg, getParentFormData) {
         this.base(arguments);
         this._getParentFormData = getParentFormData;
         var ids = [];
         var labels = [];
-        var types   = {};
+        var types = {};
         var trans = qx.locale.Manager;
-        cfg.table.forEach(function(col){
+        cfg.table.forEach(function(col) {
             ids.push(col.key);
             labels.push(trans['tr'](col.label));
-            types[col.key]   = col.type;
+            types[col.key] = col.type;
         });
-        this.setColumns(labels,ids);
-        cfg.table.forEach(function(col,i){
-            this.setColumnSortable(i,col.sortable ? true : false);
-        },this);
+        this.setColumns(labels, ids);
+        cfg.table.forEach(function(col, i) {
+            this.setColumnSortable(i, col.sortable);
+        }, this);
         this.__instanceName = cfg.name;
-        this.__types   = types;
-        this.__ids     = ids;
+        this.__types = types;
+        this.__ids = ids;
     },
 
     properties: {
@@ -44,29 +44,28 @@ qx.Class.define('callbackery.data.RemoteTableModel', {
         }
     },
 
-    members : {
+    members: {
         _getParentFormData: null,
-        __instanceName : null,
-        __types : null,
-
+        __instanceName: null,
+        __types: null,
+        __ids: null,
         /**
          * Provid our implementation to make remote table work
          */
-        _loadRowCount : function() {
+        _loadRowCount: function() {
             var that = this;
             var rpc = callbackery.data.Server.getInstance();
             var rpcArgs = {
                 formData: this.getFormData()
             };
 
-            if (this._getParentFormData){
+            if (this._getParentFormData) {
                 rpcArgs.parentFormData = this._getParentFormData();
             }
 
             rpc.callAsyncSmart(function(ret) {
                 that._onRowCountLoaded(ret);
-            }, 'getPluginData', this.__instanceName,'tableRowCount',rpcArgs
-            );
+            }, 'getPluginData', this.__instanceName, 'tableRowCount', rpcArgs);
         },
 
         /**
@@ -75,10 +74,10 @@ qx.Class.define('callbackery.data.RemoteTableModel', {
          * @param firstRow {Integer} first row to load
          * @param lastRow {Integer} last row to load
          */
-        _loadRowData : function(firstRow, lastRow) {   
+        _loadRowData: function(firstRow, lastRow) {
             var rpcArgs = {
-                firstRow : firstRow,
-                lastRow  : lastRow,
+                firstRow: firstRow,
+                lastRow: lastRow,
                 formData: this.getFormData()
             };
 
@@ -92,7 +91,7 @@ qx.Class.define('callbackery.data.RemoteTableModel', {
                 rpcArgs.sortColumn = this.getColumnId(sc);
             }
 
-            if (this._getParentFormData){
+            if (this._getParentFormData) {
                 rpcArgs.parentFormData = this._getParentFormData();
             }
 
@@ -100,16 +99,16 @@ qx.Class.define('callbackery.data.RemoteTableModel', {
             var that = this;
 
             rpc.callAsyncSmart(function(data) {
-                data.forEach(function(col){
+                data.forEach(function(col) {
                     for (var id in col) {
                         if (that.__types[id] == 'date') {
                             col[id] = new Date(col[id]);
                         }
                     }
-                }); 
+                });
                 that._onRowDataLoaded(data);
             },
-            'getPluginData', this.__instanceName,'tableData',rpcArgs);
+            'getPluginData', this.__instanceName, 'tableData', rpcArgs);
         }
     }
 });
