@@ -39,7 +39,7 @@ qx.Class.define("callbackery.ui.Screen", {
                 else {
                     that.debug('Invalid plugin type:"' + type + '"');
                 }
-            },'getPluginConfig',cfg.name);
+            },'getPluginConfig',cfg.name,getParentFormData ? getParentFormData() : null);
         });
     },
 
